@@ -1,5 +1,5 @@
 package Taskwarrior::Kusarigama::Plugin::Command::Shelf;
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 #ABSTRACT: Move tasks to and from the shelf.
 
@@ -27,7 +27,7 @@ sub on_command {
   my $self = shift;
 
   my $args = $self->args;
-  my( $cmd, $query ) = $args =~ /^task\s+shelve(?:\s+(put|get))?\s+(?<query>.*)$/g;
+  my( $cmd, $query ) = $args =~ /^task\s+shelf(?:\s+(put|get))?\s+(?<query>.*)$/g;
 
   $cmd //= 'put';
   die "no task query provided\n" unless $query;
@@ -80,7 +80,7 @@ Taskwarrior::Kusarigama::Plugin::Command::Shelf - Move tasks to and from the she
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
